Changelog

Struct Changelog 

pub struct Changelog { /* private fields */ }
Contains the entire changelog structure

Implementations

Source

impl Changelog

pub fn new(title: impl ToString) -> Self

Create a new changelog with specified title

pub fn with_description(self, description: impl ToString) -> Self

Set the changelog’s description field

pub fn add_release(self, release: Release) -> Self

Add to the changelog’s releases field

pub fn add_keep_a_changelog_message(self) -> Self

Add the keep a changelog message to the top of human oriented renderings

pub fn add_semantic_versioning_message(self) -> Self

Add the keep a semantic versioning message to the top of human oriented renderings

pub fn releases(&self) -> impl Iterator<Item = &Release>

Return an iterator of all releases in the changelog sorted by their version field

pub fn versions(&self) -> impl Iterator<Item = &Version>

Return a sorted iterator of all version numbers in the changelog. This doesn’t include unreleased as a version number