pub struct Changelog { /* private fields */ }Expand description
Contains the entire changelog structure
Implementations
Sourceimpl Changelog
impl Changelog
Sourcepub fn with_description(self, description: impl ToString) -> Self
pub fn with_description(self, description: impl ToString) -> Self
Set the changelog’s description field
Sourcepub fn add_release(self, release: Release) -> Self
pub fn add_release(self, release: Release) -> Self
Add to the changelog’s releases field
Sourcepub fn add_keep_a_changelog_message(self) -> Self
pub fn add_keep_a_changelog_message(self) -> Self
Add the keep a changelog message to the top of human oriented renderings
Sourcepub fn add_semantic_versioning_message(self) -> Self
pub fn add_semantic_versioning_message(self) -> Self
Add the keep a semantic versioning message to the top of human oriented renderings